| Title: | Resourcecode Database Configuration Data |
|---|---|
| Description: | Includes Resourcecode hindcast database (see <https://resourcecode.ifremer.fr>) configuration data: nodes locations for both the sea-state parameters and the spectra data; examples of time series of 1D and 2D surface elevation variance spectral density. |
| Authors: | Nicolas Raillard [aut, cre] (ORCID: <https://orcid.org/0000-0003-3385-5104>) |
| Maintainer: | Nicolas Raillard <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 1.0.0.9000 |
| Built: | 2026-06-01 10:58:16 UTC |
| Source: | https://github.com/Resourcecode-project/r-resourcecodedata |
This data contains the time series of 1D wave spectral data at the 'Pierre noires (6200069) wave buoy from 01-01-1994 to 31-01-1994.
rscd_1d_spectrarscd_1d_spectra
A list with 12 elements:
Longitude
Latitude
Lower frequency
Upper frequency
Surface elevation variance spectral density
Mean direction from first spectral moment
Mean direction from second spectral moment
Mean directional spreading from first spectral moment
Mean directional spreading from second spectral moment
Central frequency
A data.frame with 14 variables:
Time
Depth, positive downward
Wind intensity, at 10m above sea level
Wind direction, comes from
Current intensity, at the surface
Current direction, going to
Significant wave height
Peak wave frequency
Mean wave frequency
Mean wave frequency at spectral moment minus one
Mean wave direction at spectral peak
Directional spreading at spectral peak
Mean wave direction
Mean directional spreading
Station name
User Manual of the RESOURCECODE database https://archimer.ifremer.fr/doc/00751/86306/
This data contains the time series of 2D wave spectral data at the 'Pierre noires (6200069) wave buoy from 01-01-1994 to 31-01-1994.
rscd_2d_spectrarscd_2d_spectra
A list with 9 elements:
Longitude
Latitude
Lower frequency
Upper frequency
Surface elevation variance spectral density
Mean direction from first spectral moment
Mean direction from second spectral moment
Mean directional spreading from first spectral moment
Mean directional spreading from second spectral moment
Central frequency
Directional bins
A data.frame with 6 variables:
Time
Depth, positive downward
Wind intensity, at 10m above sea level
Wind direction, comes from
Current intensity, at the surface
Current direction, going to
Station name
User Manual of the RESOURCECODE database https://archimer.ifremer.fr/doc/00751/86306/
This data contains the coastline used to run the RESOURCECODE hindcast. This will be mainly used for plotting purpose.
rscd_coastlinerscd_coastline
A data frame with 24403 rows and 3 columns:
coordinates of the border line
depth of the border.
User Manual of the RESOURCECODE database https://archimer.ifremer.fr/doc/00751/86306/
(equivalent to a directional resolution of 10°;
rscd_dirrscd_dir
A vector of length 36 with the directional bins
User Manual of the RESOURCECODE database https://archimer.ifremer.fr/doc/00751/86306/
This data contains the location and characteristics of the 328,030 nodes where the RESOURCECODE hindcast data is available
rscd_fieldrscd_field
A data frame with 328,030 rows and 5 columns:
node number
coordinates of the nodes
depth of the node
Bottom sediment types
User Manual of the RESOURCECODE database https://archimer.ifremer.fr/doc/00751/86306/
The wave spectrum discretization considers 36 frequencies, starting from 0.0339 Hz up to 0.9526 Hz with a frequency increment factor of 1.1
rscd_freqrscd_freq
A vector 36 elements with the frequencies values
User Manual of the RESOURCECODE database https://archimer.ifremer.fr/doc/00751/86306/
The wave spectrum discretization considers 36 frequencies, starting from 0.0339 Hz up to 0.9526 Hz with a frequency increment factor of 1.1
rscd_frequency1rscd_frequency1
A vector 36 elements with the frequencies values
User Manual of the RESOURCECODE database https://archimer.ifremer.fr/doc/00751/86306/
The wave spectrum discretization considers 36 frequencies, starting from 0.0339 Hz up to 0.9526 Hz with a frequency increment factor of 1.1
rscd_frequency2rscd_frequency2
A vector 36 elements with the frequencies values
User Manual of the RESOURCECODE database https://archimer.ifremer.fr/doc/00751/86306/
This data contains the coastline of the islands used to run the RESOURCECODE hindcast, as data separated from the mainland. This will be mainly used for plotting purpose.
rscd_islandsrscd_islands
A data frame with 24403 rows and 3 columns:
coordinates of the border line
depth of the border
Unique number used to identify the island
User Manual of the RESOURCECODE database https://archimer.ifremer.fr/doc/00751/86306/
This data contains the location and characteristics of the 24,276 nodes where the full 2D spectral data is available in the RESOURCECODE data.
rscd_spectralrscd_spectral
A data frame with 24,276 rows and 5 columns:
coordinates of the nodes
Name of the spectral output point
depth of the node
Bottom sediment types
User Manual of the RESOURCECODE database https://archimer.ifremer.fr/doc/00751/86306/
This data contains the triangles of the unstructured computational mesh. This will be mainly used for plotting purpose.
rscd_trianglesrscd_triangles
A matrix with 3 rows and 566506 columns:
verticies of the triangles
node number of each vertices
User Manual of the RESOURCECODE database https://archimer.ifremer.fr/doc/00751/86306/
This data contains the variables available in the FIELD database.
rscd_variablesrscd_variables
A data frame with 88 rows and 3 columns:
short name of the variable
Full name
Unit
User Manual of the RESOURCECODE database https://archimer.ifremer.fr/doc/00751/86306/